==> digikam-7.3.0.tar.xz: digikam-7.3.0/core/utilities/advancedrename/parser/modifiers/replacemodifier.h <==
/* ============================================================
 *
 * This file is a part of digiKam project
 * https://www.digikam.org
 *
 * Date        : 2009-09-18
 * Description : a modifier for replacing text in a token result
 *
 * Copyright (C) 2009-2012 by Andi Clemens <andi dot clemens at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#ifndef DIGIKAM_REPLACE_MODIFIER_H
#define DIGIKAM_REPLACE_MODIFIER_H

// Local includes

#include "modifier.h"
#include "ruledialog.h"

class QCheckBox;

namespace Ui
{
class ReplaceModifierDialogWidget;
}

namespace Digikam
{

class ReplaceDialog : public RuleDialog
{
    Q_OBJECT

public:

    explicit ReplaceDialog(Rule* const parent);
    ~ReplaceDialog() override;

    Ui::ReplaceModifierDialogWidget* const ui;

private:

    // Disable
    explicit ReplaceDialog(QWidget*)               = delete;
    ReplaceDialog(const ReplaceDialog&)            = delete;
    ReplaceDialog& operator=(const ReplaceDialog&) = delete;
};

// --------------------------------------------------------

class ReplaceModifier : public Modifier
{
    Q_OBJECT

public:

    explicit ReplaceModifier();
    QString parseOperation(ParseSettings& settings) override;

private Q_SLOTS:

    void slotTokenTriggered(const QString& token) override;

private:

    // Disable
    explicit ReplaceModifier(QObject*)                 = delete;
    ReplaceModifier(const ReplaceModifier&)            = delete;
    ReplaceModifier& operator=(const ReplaceModifier&) = delete;
};

} // namespace Digikam

#endif // DIGIKAM_REPLACE_MODIFIER_H

==> digikam_8.8.0.orig.tar.xz: digikam-8.8.0/core/utilities/advancedrename/parser/modifiers/replacemodifier.h <==
/* ============================================================
 *
 * This file is a part of digiKam project
 * https://www.digikam.org
 *
 * Date        : 2009-09-18
 * Description : a modifier for replacing text in a token result
 *
 * SPDX-FileCopyrightText: 2009-2012 by Andi Clemens <andi dot clemens at gmail dot com>
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 *
 * ============================================================ */

#pragma once

// Local includes

#include "modifier.h"
#include "ruledialog.h"

class QCheckBox;

namespace Ui
{
class ReplaceModifierDialogWidget;
}

namespace Digikam
{

class ReplaceDialog : public RuleDialog
{
    Q_OBJECT

public:

    explicit ReplaceDialog(Rule* const parent);
    ~ReplaceDialog()                                                                      override;

public:

    Ui::ReplaceModifierDialogWidget* const ui = nullptr;

private:

    // Disable
    explicit ReplaceDialog(QWidget*)               = delete;
    ReplaceDialog(const ReplaceDialog&)            = delete;
    ReplaceDialog& operator=(const ReplaceDialog&) = delete;
};

// --------------------------------------------------------

class ReplaceModifier : public Modifier
{
    Q_OBJECT

public:

    ReplaceModifier();
    QString parseOperation(ParseSettings& settings, const QRegularExpressionMatch& match) override;

private Q_SLOTS:

    void slotTokenTriggered(const QString& token)                                         override;

private:

    // Disable
    explicit ReplaceModifier(QObject*)                 = delete;
    ReplaceModifier(const ReplaceModifier&)            = delete;
    ReplaceModifier& operator=(const ReplaceModifier&) = delete;
};

} // namespace Digikam
